==> bladerf-2024.05-1-x86_64.pkg.tar.zst: usr/share/doc/libbladeRF/html/search/groups_2.js <==
var searchData=
[
  ['calibration_0',['DC Calibration',['../group___f_n___b_l_a_d_e_r_f1___d_c___c_a_l.html',1,'']]],
  ['channel_20control_1',['Channel control',['../group___f_n___c_h_a_n_n_e_l.html',1,'']]],
  ['circuit_2',['RF Integrated Circuit',['../group___f_n___b_l_a_d_e_r_f2___l_o_w___l_e_v_e_l___r_f_i_c.html',1,'']]],
  ['clock_20buffer_3',['Clock Buffer',['../group___f_n___b_l_a_d_e_r_f2___l_o_w___l_e_v_e_l___c_l_o_c_k___b_u_f_f_e_r.html',1,'']]],
  ['clock_20input_20selection_4',['Clock input selection',['../group___f_n___b_l_a_d_e_r_f2___l_o_w___l_e_v_e_l___c_l_o_c_k___b_u_f_f_e_r___s_e_l_e_c_t.html',1,'']]],
  ['clock_20output_20control_5',['Clock output control',['../group___f_n___b_l_a_d_e_r_f2___l_o_w___l_e_v_e_l___c_l_o_c_k___b_u_f_f_e_r___o_u_t_p_u_t.html',1,'']]],
  ['clock_20port_20control_6',['SMB clock port control',['../group___f_n___s_m_b___c_l_o_c_k.html',1,'']]],
  ['codes_7',['Error codes',['../group___r_e_t_c_o_d_e_s.html',1,'']]],
  ['configuration_20gpio_8',['Configuration GPIO',['../group___f_n___c_o_n_f_i_g___g_p_i_o.html',1,'']]],
  ['constants_9',['Flash image format constants',['../group___b_l_a_d_e_r_f___f_l_a_s_h___c_o_n_s_t_a_n_t_s.html',1,'']]],
  ['constants_20deprecated_10',['Constants (deprecated)',['../group___b_l_a_d_e_r_f1___c_o_n_s_t_a_n_t_s.html',1,'']]],
  ['control_11',['Control',['../group___f_n___b_l_a_d_e_r_f2___b_i_a_s___t_e_e.html',1,'Bias Tee Control'],['../group___f_n___b_l_a_d_e_r_f2___l_o_w___l_e_v_e_l___p_l_l.html',1,'Phase Detector/Freq. Synth Control'],['../group___f_n___b_l_a_d_e_r_f2___l_o_w___l_e_v_e_l___r_f___s_w_i_t_c_h_i_n_g.html',1,'RF Switching Control'],['../group___f_n___t_r_i_g_g_e_r___c_o_n_t_r_o_l.html',1,'Trigger Control']]],
  ['control_12',['control',['../group___f_n___c_h_a_n_n_e_l.html',1,'Channel control'],['../group___f_n___b_l_a_d_e_r_f2___l_o_w___l_e_v_e_l___c_l_o_c_k___b_u_f_f_e_r___o_u_t_p_u_t.html',1,'Clock output control'],['../group___f_n___s_m_b___c_l_o_c_k.html',1,'SMB clock port control']]],
  ['correction_13',['Correction',['../group___f_n___c_o_r_r.html',1,'']]]
];

==> bladerf-2025.10-1-x86_64.pkg.tar.zst: usr/share/doc/libbladeRF/html/search/groups_2.js <==
var searchData=
[
  ['calibration_0',['Calibration',['../group___f_n___b_l_a_d_e_r_f1___d_c___c_a_l.html',1,'DC Calibration'],['../group___f_n___c_a_l.html',1,'Gain Calibration']]],
  ['channel_20control_1',['Channel control',['../group___f_n___c_h_a_n_n_e_l.html',1,'']]],
  ['circuit_2',['RF Integrated Circuit',['../group___f_n___b_l_a_d_e_r_f2___l_o_w___l_e_v_e_l___r_f_i_c.html',1,'']]],
  ['clock_20buffer_3',['Clock Buffer',['../group___f_n___b_l_a_d_e_r_f2___l_o_w___l_e_v_e_l___c_l_o_c_k___b_u_f_f_e_r.html',1,'']]],
  ['clock_20input_20selection_4',['Clock input selection',['../group___f_n___b_l_a_d_e_r_f2___l_o_w___l_e_v_e_l___c_l_o_c_k___b_u_f_f_e_r___s_e_l_e_c_t.html',1,'']]],
  ['clock_20output_20control_5',['Clock output control',['../group___f_n___b_l_a_d_e_r_f2___l_o_w___l_e_v_e_l___c_l_o_c_k___b_u_f_f_e_r___o_u_t_p_u_t.html',1,'']]],
  ['clock_20port_20control_6',['SMB clock port control',['../group___f_n___s_m_b___c_l_o_c_k.html',1,'']]],
  ['codes_7',['Error codes',['../group___r_e_t_c_o_d_e_s.html',1,'']]],
  ['configuration_20gpio_8',['Configuration GPIO',['../group___f_n___c_o_n_f_i_g___g_p_i_o.html',1,'']]],
  ['constants_9',['Flash image format constants',['../group___b_l_a_d_e_r_f___f_l_a_s_h___c_o_n_s_t_a_n_t_s.html',1,'']]],
  ['constants_20deprecated_10',['Constants (deprecated)',['../group___b_l_a_d_e_r_f1___c_o_n_s_t_a_n_t_s.html',1,'']]],
  ['control_11',['Control',['../group___f_n___b_l_a_d_e_r_f2___b_i_a_s___t_e_e.html',1,'Bias Tee Control'],['../group___f_n___b_l_a_d_e_r_f2___l_o_w___l_e_v_e_l___p_l_l.html',1,'Phase Detector/Freq. Synth Control'],['../group___f_n___b_l_a_d_e_r_f2___l_o_w___l_e_v_e_l___r_f___s_w_i_t_c_h_i_n_g.html',1,'RF Switching Control'],['../group___f_n___t_r_i_g_g_e_r___c_o_n_t_r_o_l.html',1,'Trigger Control']]],
  ['control_12',['control',['../group___f_n___c_h_a_n_n_e_l.html',1,'Channel control'],['../group___f_n___b_l_a_d_e_r_f2___l_o_w___l_e_v_e_l___c_l_o_c_k___b_u_f_f_e_r___o_u_t_p_u_t.html',1,'Clock output control'],['../group___f_n___s_m_b___c_l_o_c_k.html',1,'SMB clock port control']]],
  ['correction_13',['Correction',['../group___f_n___c_o_r_r.html',1,'']]]
];
